#
# spec file for package libassuan
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           libassuan
VCS: https://src.suse.de/SLFO-pool/libassuan#6825efb082a36e72f14ef68472b175315a2a8fde496b6ba09750bf04d90937e3
Version:        2.5.6
Release:        slfo.1.1_1.2
Summary:        IPC library used by GnuPG version 2
License:        GPL-3.0-or-later AND LGPL-2.1-or-later
Group:          Development/Libraries/C and C++
URL:            https://www.gnupg.org/related_software/libassuan/index.en.html
Source0:        ftp://ftp.gnupg.org/gcrypt/libassuan/%{name}-%{version}.tar.bz2
Source1:        baselibs.conf
Source2:        ftp://ftp.gnupg.org/gcrypt/libassuan/%{name}-%{version}.tar.bz2.sig
# http://www.gnupg.org/signature_key.en.html
Source3:        libassuan.keyring
BuildRequires:  libgpg-error-devel >= 1.17
Requires:       %{install_info_prereq}

%description
Libassuan is the IPC library used by gpg2 (GnuPG version 2)

%package -n libassuan0
Summary:        IPC library used by GnuPG version 2
Group:          Development/Libraries/C and C++

%description -n libassuan0
Libassuan is the IPC library used by gpg2 (GnuPG version 2)

%package devel
Summary:        IPC library used by GnuPG version 2
Group:          Development/Libraries/C and C++
Requires:       libassuan0 = %{version}
Requires:       libgpg-error-devel

%description devel
Libassuan is the IPC library used by gpg2 (GnuPG version 2)

gpgme also uses libassuan to communicate with a libassuan-enabled GnuPG
v2 server, but it uses it's own copy of libassuan.

%prep
%setup -q

%build
# Compile with PIC, library is linked into shared libraries:
export CFLAGS="%{optflags} $(getconf LFS_CFLAGS)"
export LDFLAGS="-fPIC"
%configure
%make_build

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print

%check
%make_build check

%post -n libassuan0 -p /sbin/ldconfig
%postun -n libassuan0 -p /sbin/ldconfig

%post devel
%install_info --info-dir=%{_infodir} %{_infodir}/assuan.info.gz

%postun devel
%install_info_delete --info-dir=%{_infodir} %{_infodir}/assuan.info.gz

%files -n libassuan0
%license COPYING
%doc AUTHORS ChangeLog NEWS README THANKS
%{_libdir}/libassuan.so.*

%files devel
%{_libdir}/pkgconfig/libassuan.pc
%{_infodir}/assuan*
%{_includedir}/*.h
%{_bindir}/*-config
%dir %{_datadir}/aclocal
%{_datadir}/aclocal/*.m4
%{_libdir}/libassuan.so

%changelog
* Tue Jun 20 2023 pmonreal@suse.com
- Update to 2.5.6:
  * Fix logging of confidential data. [rA0fc31770fa]
  * Fix memory wiping. [T5977]
  * Fix macOS build problem. [T5440,T5610]
  * Upgrade autoconf stuff.
  * Release-info: https://dev.gnupg.org/T6542
* Fri Mar 26 2021 andreas.stieger@gmx.de
- update to 2.5.5:
  * Fix a crash in the logging code
  * Upgrade autoconf
* Sat Oct 24 2020 andreas.stieger@gmx.de
- update to 2.5.4:
  * Fix some minor build annoyances
* Mon Feb 11 2019 kbabioch@suse.de
- Update to 2.5.3:
  * Add a timeout for writing to a SOCKS5 proxy.
  * Add workaround for a problem with LD_LIBRARY_PATH on newer systems.
* Wed Dec 19 2018 schwab@suse.de
- qemu-disable-fdpassing-test.patch: remove
* Thu Dec 13 2018 atoptsoglou@suse.com
-Update to 2.5.2:
  * configure.ac: Bump LT version to C8/A8/R2
  * include libassuan.pc in the spec file
* Thu Feb 22 2018 fvogt@suse.com
- Use %%license (boo#1082318)
* Mon Dec 11 2017 astieger@suse.com
- libassuan 2.5.1:
  * New function to change the system hooks for the socket
    interface (assuan_sock_set_system_hooks)
* Mon Dec  4 2017 astieger@suse.com
- libassuan 2.4.5:
  * fixes for platforms other than GNU/Linux
* Tue Nov 21 2017 astieger@suse.com
- libassuan 2.4.4:
  * New configure option --disable-doc
  * Fix the use of nanosleep
  * Portability fix for systems not defining INADDR_LOOPBACK
* Wed Nov  9 2016 schwab@suse.de
- qemu-disable-fdpassing-test.patch: disable fdpassing test when running
  under qemu-linux-user
* Mon Jul 18 2016 astieger@suse.com
- libassuan 2.4.3:
  * Allow socket redirection with assuan_socket_connect.
  * Speedup spawning programs on Linux
  * Fix minor memory leaks
* Thu Dec  3 2015 astieger@suse.com
- libassuan 2.4.2:
  * The nPth version of the connect system hook does now wrap the
  call with npth_unprotec/npth_protect to avoid blocking during a
  connect.
  * Add feature to assuan_sock_connect_byname to test for SOCKS5
  availability.
* Sat Nov 28 2015 astieger@suse.com
- libassuan 2.4.1:
  * In Tor mode fallback to port 9150 if 9050 is not listening.
* Thu Nov  5 2015 astieger@suse.com
- libassuan 2.4.0:
  * New flags "socks" and "tor-mode" for assuan_sock_{set,get}_flag.
  * New function assuan_sock_connect_byname.
  * Require at least libgpg-error 1.17.
  * Interface changes relative to the 2.3.0 release:
    assuan_sock_connect_byname    NEW.
    ASSUAN_SOCK_TOR               NEW.
    ASSUAN_SOCK_SOCKS             NEW.
    assuan_sock_set_flag          EXTENDED.
    assuan_sock_get_flag          EXTENDED.
* Fri Aug 28 2015 astieger@suse.com
- libassuan 2.3.0:
  * Now wipes out the memory of the context structure before freeing.
  The context may have stored sensitive data in its line buffers.
  * Fixed a problem with the data length limit in assuan_inquire.
  * Returns GPG_ERR_SOURCE_ASSUAN with errors from functions w/o a
  context.
  * Two new functions to tweak the behaviour of the socket wrappers.
  * By default build without a build timestamp.
  * Interface changes relative to the 2.2.1 release:
  assuan_sock_set_flag     NEW.
  assuan_sock_get_flag     NEW.
* Tue May 12 2015 astieger@suse.com
- libassuan 2.2.1:
  * Documentation updates.
  * Fixes for platforms other than GNU/Linux
* Sun Dec 28 2014 andreas.stieger@gmx.de
- libassuan 2.2.0:
  * Added support for socket redirection.
  * Interface changes relative to the 2.1.3 release:
  assuan_sock_set_sockaddr_un  NEW.
- fix SLE 11 SP2 build (make install)
* Sat Nov  8 2014 andreas.stieger@gmx.de
- update to 2.1.3:
  + Performance fix for a platform other than GNU/Linux
* Sun Aug 17 2014 andreas.stieger@gmx.de
- update to 2.1.2:
  * Added support for ppc64le.
* Mon Aug 19 2013 andreas.stieger@gmx.de
- update to 2.1.1
  * no changes on the GNU/Linux platform
- includes changes from 2.1.0:
  * Support for the nPth library.
  * Add assuan_check_version and two version macros.
  * Interface changes relative to the 2.0.3 release:
    ASSUAN_SYSTEM_NPTH_IMPL  NEW macro.
    ASSUAN_SYSTEM_NPTH       NEW macro.
    __assuan_read            NEW (private).
    __assuan_write           NEW (private).
    __assuan_recvmsg         NEW (private).
    __assuan_sendmsg         NEW (private).
    __assuan_waitpid         NEW (private).
    ASSUAN_VERSION           NEW macro.
    ASSUAN_VERSION_NUMBER    NEW macro.
    assuan_check_version     NEW.
- add tarball signature and keyring
- run unit tests during build
- libgpg-error requirement is >= 1.8
* Mon Jun 10 2013 crrodriguez@opensuse.org
- build with LFS support in 32bit archs to be consistent
  with the rest of the system, no good will come when LFS
  enabled callers talk to non-LFS libraries.
* Mon Nov 26 2012 cfarrell@suse.com
- license update: GPL-3.0+ and LGPL-2.1+
  Look at COPYING, COPYING.LIB and README
* Fri Nov 16 2012 andreas.stieger@gmx.de
- update to Libassuan 2.0.3
  - Make assuan_get_pid work correctly for pipe server.
  - Interface changes relative to the 2.0.2 release:
  * ASSUAN_FORCE_CLOSE (NEW)
* Sun Dec 25 2011 coolo@suse.com
- own aclocal directory
* Sun Oct  2 2011 crrodriguez@opensuse.org
- Remove Requires/BuildRequires on libpth, this package
  no longer uses this library.
* Fri Jul 29 2011 puzel@novell.com
- update to libassuan-2.0.2
  - A new flag may now be used to convey comments via
  assuan_transact.
  - A new flag value may now be used to disable logging.
  - The gpgcedev.c driver now provides a log device.
  - It is now possible to overwrite socket and connect functions in
  struct assuan_system_hooks.
  - Interface changes relative to the 2.0.1 release:
  ASSUAN_CONVEY_COMMENTS   NEW.
  ASSUAN_NO_LOGGING        NEW.
  assuan_system_hooks_t    CHANGED: Added socket and connect members.
  ASSUAN_SYSTEM_HOOKS_VERSION  CHANGED: Bumped to 2.
  assuan_register_pre_cmd_notify  NEW.
- use spec-cleaner
* Sun Oct 31 2010 jengelh@medozas.de
- Use %%_smp_mflags
* Tue Aug 17 2010 puzel@novell.com
- update to libassuan-2.0.1
  * Input and output notification handler can now really access the
  parsed fd as stated in the manual.
  * Cleaned up the logging.
  * Interface changes relative to the 2.0.0 release:
  assuan_free               NEW
  _assuan_w32ce_create_pipe NEW
  ASSUAN_LOG_CONTROL        NEW
* Fri Apr  9 2010 chris@computersalat.de
- fixed deps
  o libgpg-error-devel >= 1.4
* Thu Apr  8 2010 chris@computersalat.de
- fix deps for pth
  pth < 1120 >= libpth-devel
- sort TAGS
* Tue Apr  6 2010 ro@suse.de
- add baselibs.conf (needed for libgpgme)
* Wed Mar 31 2010 puzel@novell.com
- update to libassuan-2.0.0
  * Now using libtool and builds a DSO.
  * Lots of interface cleanups.
  * Pth support has changed. This now follows the same style as
  libgcrypt by setting system hook callbacks.
- split package to libassuan0 and libassuan-devel
* Thu Jun 11 2009 puzel@suse.cz
- change BuildRequires: (pth-devel -> libpth-devel)
* Mon Jun  1 2009 puzel@suse.cz
- BuildRequires: pth-devel
* Wed Jul 16 2008 puzel@suse.cz
- update to 1.0.5
  * minor fixes
  * build library as PIC
* Tue Jan  8 2008 sassmann@suse.de
- updated to version 1.0.4, which is required by GnuPG 2.0.8
  * Switched license of the library code back to LGPLv2.1
  * config.sub, config.guess: Update to version 2007-11-19
* Fri Aug 10 2007 bk@suse.de
- updated to 1.0.2, which is required by GnuPG 2.0.5 (and later)
  * Changed license to LGPLv3.
  * New flag ASSUAN_CONFIDENTIAL to return the state of confidential logging.
  * Assorted bug fixed and code cleanups.
- added Requires: pth (needed because it's built against it)
- dropped Requires: openct-devel pcsc-lite-devel (no relation to them)
* Thu Jul 26 2007 sbrabec@suse.cz
- Build with PIC.
- Renamed binary package to libassuan devel.
* Wed Jan 24 2007 ltinkl@suse.cz
- updated to 1.0.1, added pth to BuildRequires
  * New function: assuan_set_io_monitor.
  * New function: assuan_register_post_cmd_notify.
  * Fixed a memory leak.
  * Finished the manual.
  * Portability fixes.
  * Pth is not anymore linked by means of weak symbol tricks.  It is
  now required to link to the pth version of libassuan.  New autoconf
  macros are provided to to check for this.  The pth version is only
  build if Pth is available.
  * configure does now check that descripotor passing is available.  A
  way to check at runtime for this is also provided
  * A fix to make CANCEL work again in Pinentries.
  * Internal cleanups to make inclusion of the code into libraries
  easier.
  * Made clear that the software is under the LGPL.
  * New function assuan_set_assuan_err_source.  All gpg-error enabled
  software should call this right at startup to switch libassuan into
  the gpg-error style mode.  All error codes are then returned as
  gpg-error style codes (GPG_ERR_ASS_* as well as others).
  If the new macro _ASSUAN_ONLY_GPG_ERRORS is defned all old
  definitions are excluded from assuan.h.
  * Logging of hex strings is now limited to 16 bytes.  To enable
  printing of the full data, a new environment variable
  ASSUAN_FULL_LOGGING may be set to any value.
  * Removed the assuan_domain_* functions.
  * New functions assuan_pipe_connect_ext and assuan_socket_connect_ext
  to allow connections on a socketpair and to pass descriptors.
  * New function assuan_get_peercred.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Nov  8 2005 dmueller@suse.de
- don't build as root
* Tue Jul 12 2005 postadal@suse.cz
- updated to version 0.6.10
* Wed Jan 12 2005 adrian@suse.de
- update to version 0.6.9
* Mon Jul 12 2004 adrian@suse.de
- initial package of version 0.6.6
